summaryrefslogtreecommitdiffstats
path: root/certmanager/certificatewizardimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/certificatewizardimpl.cpp')
-rw-r--r--certmanager/certificatewizardimpl.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/certmanager/certificatewizardimpl.cpp b/certmanager/certificatewizardimpl.cpp
index 4924cd0b..d24c7df9 100644
--- a/certmanager/certificatewizardimpl.cpp
+++ b/certmanager/certificatewizardimpl.cpp
@@ -108,14 +108,14 @@ static bool availForMod( const TQLineEdit * le ) {
}
/*
* Constructs a CertificateWizardImpl which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The wizard will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal wizard.
*/
-CertificateWizardImpl::CertificateWizardImpl( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : CertificateWizard( tqparent, name, modal, fl )
+CertificateWizardImpl::CertificateWizardImpl( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : CertificateWizard( parent, name, modal, fl )
{
// don't allow to go to last page until a key has been generated
setNextEnabled( generatePage, false );
@@ -108,14 +108,14 @@ static bool availForMod( const TQLineEdit * le ) {
}
/*
- * Constructs a CertificateWizardImpl which is a child of 'tqparent', with the
+ * Constructs a CertificateWizardImpl which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*